pub struct SshConnectionManager { /* private fields */ }Expand description
SSH connection pool manager.
Manages a cache of SSH connections with automatic reconnection and connection pooling. Connections are cached for 5 minutes of inactivity.
Implementations
Sourceimpl SshConnectionManager
impl SshConnectionManager
Sourcepub async fn get(
&self,
user: String,
addr: String,
port: u16,
password: String,
enable_password: Option<String>,
handler: DeviceHandler,
) -> Result<Sender<CmdJob>, ConnectError>
pub async fn get( &self, user: String, addr: String, port: u16, password: String, enable_password: Option<String>, handler: DeviceHandler, ) -> Result<Sender<CmdJob>, ConnectError>
Gets a cached SSH client or creates a new one.
This method first checks the cache for an existing healthy connection. If found and the connection parameters match, it reuses the connection. Otherwise, it creates a new connection, caches it, and returns the sender.
Sourcepub async fn get_with_security(
&self,
user: String,
addr: String,
port: u16,
password: String,
enable_password: Option<String>,
handler: DeviceHandler,
security_options: ConnectionSecurityOptions,
) -> Result<Sender<CmdJob>, ConnectError>
pub async fn get_with_security( &self, user: String, addr: String, port: u16, password: String, enable_password: Option<String>, handler: DeviceHandler, security_options: ConnectionSecurityOptions, ) -> Result<Sender<CmdJob>, ConnectError>
Gets a cached SSH client or creates a new one with explicit security options.