pub struct TemplateDetectProfile {
pub initial_rules: Vec<TemplateProbeRule>,
pub probes: Vec<TemplateProbe>,
}Expand description
Declarative detect profile attached to one built-in template.
Fields
initial_rules: Vec<TemplateProbeRule>probes: Vec<TemplateProbe>Trait Implementations
Sourceimpl Clone for TemplateDetectProfile
impl Clone for TemplateDetectProfile
Sourcefn clone(&self) -> TemplateDetectProfile
fn clone(&self) -> TemplateDetectProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateDetectProfile
impl Debug for TemplateDetectProfile
Sourceimpl Default for TemplateDetectProfile
impl Default for TemplateDetectProfile
Sourcefn default() -> TemplateDetectProfile
fn default() -> TemplateDetectProfile
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TemplateDetectProfile
impl<'de> Deserialize<'de> for TemplateDetectProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateDetectProfile
impl JsonSchema for TemplateDetectProfile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourcefn always_inline_schema() -> bool
fn always_inline_schema() -> bool
👎Deprecated:
Use inline_schema() instead
Only included for backward-compatibility - use
inline_schema() instead“. Read moreSourceimpl PartialEq for TemplateDetectProfile
impl PartialEq for TemplateDetectProfile
Sourcefn eq(&self, other: &TemplateDetectProfile) -> bool
fn eq(&self, other: &TemplateDetectProfile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TemplateDetectProfile
impl Serialize for TemplateDetectProfile
impl Eq for TemplateDetectProfile
impl StructuralPartialEq for TemplateDetectProfile