pub struct TemplateProbe {
pub command: String,
pub rules: Vec<TemplateProbeRule>,
pub error_patterns: Vec<String>,
}Expand description
One probe command plus the rules used to score its output.
Fields
command: Stringrules: Vec<TemplateProbeRule>error_patterns: Vec<String>Trait Implementations
Sourceimpl Clone for TemplateProbe
impl Clone for TemplateProbe
Sourcefn clone(&self) -> TemplateProbe
fn clone(&self) -> TemplateProbe
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateProbe
impl Debug for TemplateProbe
Sourceimpl<'de> Deserialize<'de> for TemplateProbe
impl<'de> Deserialize<'de> for TemplateProbe
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TemplateProbe
Sourceimpl JsonSchema for TemplateProbe
impl JsonSchema for TemplateProbe
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourcefn always_inline_schema() -> bool
fn always_inline_schema() -> bool
👎Deprecated:
Use inline_schema() instead
Only included for backward-compatibility - use
inline_schema() instead“. Read moreSourceimpl PartialEq for TemplateProbe
impl PartialEq for TemplateProbe
Sourcefn eq(&self, other: &TemplateProbe) -> bool
fn eq(&self, other: &TemplateProbe) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TemplateProbe
impl Serialize for TemplateProbe
impl StructuralPartialEq for TemplateProbe